@@ -11,8 +11,8 @@ BEGIN {
     }
 }
 our $AUTHORITY = 'cpan:BEROV';
-our $VERSION   = '0.54';
-our $CODENAME  = 'U+2C03 GLAGOLITIC CAPITAL LETTER GLAGOLI (Ⰳ)';
+our $VERSION   = '0.55';
+our $CODENAME  = 'U+2C04 GLAGOLITIC CAPITAL LETTER DOBRO (Ⰴ)';
 
 use Ado::Control;
 use Ado::Sessions;
@@ -75,9 +75,8 @@ sub load_routes {
         my $r = $params ? $routes->route($pattern, %$params) : $routes->route($pattern);
 
         if ($over) {
-            if    (ref $over eq 'ARRAY') { $r->over(@$over); }
-            elsif (ref $over eq 'HASH')  { $r->over(%$over); }
-            else                         { $r->over($over); }
+            if   (ref $over eq 'HASH') { $r->over(%$over); }
+            else                       { $r->over($over); }
         }
         if ($via) {
             $r->via(@$via);
